# Changelog


## 0.6.0 (5DEC17)

 * the `upload` command is fully functional and can even replace uploaded packages. It will guide you through the setup process.
 * added command `config` to check the configuration
 * the `build` command ignores more files and prevents those from being packaged.
  
## 0.5.1 (4DEC17)
 * bugfix release
  
## 0.5.0 (4DEC17)
 * removed shutil for py2.7 compatibility
 * improved upload handling
 * added build and upload runners on the tests
 * updated the `create` command to include the creation of the virtualenv
  
## 0.3.0 (1NOV17)

Third prerelease.
 * The following commands are functional: `new`, `build`, `upload`.
 